@@ -1,8 +1,15 @@
 "epi.kappa" <- function(dat, method = "fleiss", alternative = c("two.sided", "less", "greater"), conf.level = 0.95){
+
+  is.wholenumber <- function(x, tol = .Machine$double.eps^0.5){
+    abs(x - round(x)) < tol
+  }
+     
+  if (sum(is.wholenumber(dat)) != nrow(dat) * ncol(dat)) 
+    stop("Error: epi.kappa requires whole numbers in each cell of the input table dat")
    
   if (nrow(dat) != ncol(dat)) 
-    stop("Error: epi.kappa dat requires a table with equal numbers of rows and columns")
-    
+    stop("Error: epi.kappa requires input table dat to have equal numbers of rows and columns")
+
   N. <- 1 - ((1 - conf.level) / 2)
   z <- qnorm(N., mean = 0, sd = 1)
   lower <- "lower"
@@ -17,7 +24,7 @@
     # Turn cell frequencies into proportions:
     ndat <- dat / n
     
-    # Overall proportion of observed agreement, pO
+    # Overall proportion of observed agreement, pO:
     tmp <- zexact(dat = as.matrix(cbind(sum(diag(dat)), sum(dat))), conf.level = conf.level)
     pO.p <- as.numeric(tmp[,1])
     pO.l <- as.numeric(tmp[,2])
@@ -144,7 +151,7 @@
   
   
   # ================================================================
-  # Population adjusted, bias corrected kappa (after Byrt et al. 1993, added 010814):
+  # Population adjusted, bias corrected kappa (PABAK, after Byrt et al. 1993, added 010814):
   
   pabak.p <- 2 * pO.p - 1
   pabak.l <- 2 * pO.l - 1   
@@ -155,7 +162,7 @@
   # Test of effect (Equation 18.14 in Fleiss). Code for p-value taken from z.test function in TeachingDemos package:
   
   effect.z <- kappa.p / kappa.se
-  alternative <- match.arg(alternative)
+  alternative <- match.arg(alternative, choices = c("two.sided", "less", "greater"))
   
   p.effect <- switch(alternative, two.sided = 2 * pnorm(abs(effect.z), lower.tail = FALSE), less = pnorm(effect.z), greater = pnorm(effect.z, lower.tail = FALSE))
   
@@ -184,7 +191,7 @@
     rval <- list(prop.agree = prop.agree, pindex = pindex, bindex = bindex, pabak = pabak, kappa = kappa, z = z, mcnemar = mcnemar)
   }
 
-  if(nrow(dat >= 2)){
+  else if(nrow(dat >= 2)){
     prop.agree <- data.frame(obs = pO.p, exp = pE.p)
     pabak <- data.frame(est = pabak.p, lower = pabak.l, upper = pabak.u)
     kappa <- data.frame(est = kappa.p, se = kappa.se, lower = kappa.l, upper = kappa.u)
