@@ -1,4 +1,4 @@
-epi.ssninfc <- function(treat, control, sigma, delta, n, power, r = 1, nfractional = FALSE, alpha){
+epi.ssninfc <- function(treat, control, sigma, delta, n, power, r = 1, nfractional = FALSE, alpha = 0.05){
 
   # Stop if a negative value for delta entered:
   if (delta < 0){
@@ -70,4 +70,10 @@ epi.ssninfc <- function(treat, control, sigma, delta, n, power, r = 1, nfraction
     rval <- list(n.total = n.total, n.treat = n.treat, n.control = n.control, delta = delta, power = power)
   }
   rval
-}  
\ No newline at end of file
+}  
+
+# epi.ssninfc(treat = 110, control = 110, sigma = 50, delta = 40, n = NA, power = 0.90, r = 1, nfraction = FALSE, alpha = 0.05)
+
+# n.treat = 27, n.control = 27, n.total = 54
+
+# Agrees with https://www.sealedenvelope.com/power/continuous-noninferior/
