@@ -44,7 +44,7 @@ dat.df <- dat.df[sort.list(dat.df$est),]
 dat.df$rank <- 1:nrow(dat.df)
 dat.df$labels <- dat.df$rname
 
-## ----dfreq01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:dfreq01}Figure 1: Ranked error bar plot showing the prevalence of disease (and its 95% confidence interval) for 100 population units."----
+## ----dfreq01-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:dfreq01}Figure 1: Ranked error bar plot showing the number of prevalent cases of disease (and its 95% confidence interval) for every 100 population units."----
 ggplot(data = dat.df, aes(x = rank, y = est)) +
   theme_bw() +
   geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.1) +
@@ -63,7 +63,7 @@ ndelete <- function(x, n){
 
 dat.df$labels <- ndelete(x = dat.df$rname, n = 2)
 
-## ----dfreq02-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:dfreq02}Figure 2: Ranked error bar plot showing the prevalence of disease (and its 95% confidence interval) for 100 population units."----
+## ----dfreq02-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:dfreq02}Figure 2: Ranked error bar plot showing the number of prevalent cases of disease (and its 95% confidence interval) for every 100 population units."----
 ggplot(data = dat.df, aes(x = rank, y = est)) +
   theme_bw() +
   geom_errorbar(aes(ymin = lower, ymax = upper), width = 0.1) +
@@ -81,12 +81,13 @@ fodate <- sample(x = odate, size = n.females, replace = TRUE)
 
 dat.df <- data.frame(sex = c(rep("Male", n.males), rep("Female", n.females)), 
    odate = c(modate, fodate))
+dat.df$odate <- as.Date(dat.df$odate, format = "%Y-%m-%d")
 
 # Sort the data in order of odate:
 dat.df <- dat.df[sort.list(dat.df$odate),] 
 
-## ----epicurve01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve01}Figure 3: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024."----
-ggplot(data = dat.df, aes(x = as.Date(odate))) +
+## ----epicurve01-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve01}Figure 3: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024."----
+ggplot(data = dat.df, aes(x = odate)) +
   theme_bw() +
   geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("7 days"), labels = date_format("%d %b"), 
@@ -94,8 +95,7 @@ ggplot(data = dat.df, aes(x = as.Date(odate))) +
   scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1))
 
-## ----epicurve02-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve02}Figure 4: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024. Superimposed on this plot is a smoothed estimate of case density."----
-
+## ----epicurve02-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve02}Figure 4: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024. Superimposed on this plot is a smoothed estimate of case density."----
 ggplot(data = dat.df, aes(x = odate)) +
   theme_bw() +
   geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
@@ -105,54 +105,53 @@ ggplot(data = dat.df, aes(x = odate)) +
   scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1))
 
-
-## ----epicurve03-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve03}Figure 5: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, conditioned by sex."----
-ggplot(data = dat.df, aes(x = as.Date(odate))) +
+## ----epicurve03-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve03}Figure 5: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, conditioned by sex."----
+ggplot(data = dat.df, aes(x = odate)) +
   theme_bw() +
   geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
-  scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
-     name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
-  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
-  facet_grid( ~ sex)
-
-## ----epicurve04-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve04}Figure 6: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, conditioned by sex. An event that occurred on 31 October 2024 is indicated by the vertical dashed line."----
-ggplot(data = dat.df, aes(x = as.Date(odate))) +
-  theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
-  scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
-     name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
-  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
   facet_grid( ~ sex) +
-  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2024", format = "%d/%m/%Y"))), 
+  scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
+     name = "Date") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
+  theme(axis.text.x = element_text(angle = 90, hjust = 1))
+
+## ----epicurve04-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve04}Figure 6: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, conditioned by sex. An event that occurred on 31 October 2024 is indicated by the vertical dashed line."----
+ggplot(data = dat.df, aes(x = odate)) +
+  theme_bw() +
+  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
+  facet_grid( ~ sex) +
+  scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
+     name = "Date") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
+  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
+  geom_vline(aes(xintercept = as.Date("31/10/2024", format = "%d/%m/%Y")), 
    linetype = "dashed")
 
-## ----epicurve05-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve05}Figure 7: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, grouped by sex."----
-ggplot(data = dat.df, aes(x = as.Date(odate), group = sex, fill = sex)) +
+## ----epicurve05-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve05}Figure 7: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, grouped by sex."----
+ggplot(data = dat.df, aes(x = odate, group = sex, fill = sex)) +
   theme_bw() +
   geom_histogram(binwidth = 7, colour = "gray", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
      name = "Date") +
   scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
-  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2024", format = "%d/%m/%Y"))), 
+  geom_vline(aes(xintercept = as.Date("31/10/2024", format = "%d/%m/%Y")), 
    linetype = "dashed") + 
   scale_fill_manual(values = c("#d46a6a", "#738ca6"), name = "Sex") +
-  theme(legend.position = "inside", legend.position.inside = c(0.90, 0.80))
+  theme(legend.position = "bottom")
 
-## ----epicurve06-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve06}Figure 8: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, grouped by sex."----
-ggplot(data = dat.df, aes(x = as.Date(odate), group = sex, fill = sex)) +
+## ----epicurve06-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve06}Figure 8: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2024, grouped by sex."----
+ggplot(data = dat.df, aes(x = odate, group = sex, fill = sex)) +
   theme_bw() +
   geom_histogram(binwidth = 7, colour = "gray", linewidth = 0.1, position = "dodge") +
   scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
      name = "Date") +
   scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
-  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2024", format = "%d/%m/%Y"))), 
+  geom_vline(aes(xintercept = as.Date("31/10/2024", format = "%d/%m/%Y")), 
    linetype = "dashed") + 
   scale_fill_manual(values = c("#d46a6a", "#738ca6"), name = "Sex") + 
-  theme(legend.position = "inside", legend.position.inside = c(0.90, 0.80))
+  theme(legend.position = "bottom")
 
 ## -----------------------------------------------------------------------------
 edate <- seq(from = as.Date("2024-02-24"), to = as.Date("2024-07-20"), by = 1)
@@ -166,7 +165,7 @@ dat.df <- data.frame(edate, ncas)
 dat.df$edate <- as.Date(dat.df$edate, format = "%Y-%m-%d")
 head(dat.df)
 
-## ----epicurve07-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve07}Figure 9: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2024 to 20 July 2024."----
+## ----epicurve07-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve07}Figure 9: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2024 to 20 July 2024."----
 ggplot() +
   theme_bw() +
   geom_histogram(dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", linewidth = 0.1) +
@@ -178,8 +177,7 @@ ggplot() +
 ## -----------------------------------------------------------------------------
 max(cumsum(dat.df$ncas))
 
-## ----epicurve08-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve08}Figure 10: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2024 to 20 July 2024. Superimposed on this plot is a line showing cumulative case numbers."----
-
+## ----epicurve08-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve08}Figure 10: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2024 to 20 July 2024. Superimposed on this plot is a line showing cumulative case numbers."----
 ggplot() +
   theme_bw() +
   geom_histogram(data = dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", linewidth = 0.1) +
@@ -191,8 +189,7 @@ ggplot() +
   guides(fill = "none") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1))
 
-## ----epicurve09-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve09}Figure 11: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2024 to 20 July 2024. Superimposed on this plot is the 5-day rolling mean number of cases per day."----
-
+## ----epicurve09-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:epicurve09}Figure 11: Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2024 to 20 July 2024. Superimposed on this plot is the 5-day rolling mean number of cases per day."----
 dat.df$rncas <- rollmean(x = dat.df$ncas, k = 5, fill = NA)
 
 ggplot() +
@@ -210,7 +207,7 @@ library(sf); library(spData); library(plyr); library(RColorBrewer); library(sp);
 
 nyage65utm.sf <- st_read(dsn = system.file("shapes/NY8_bna_utm18.gpkg", package = "spData")[1])
 
-## ----spatial01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:spatial01}Figure 12: Map of an area of New York, USA showing for each census tract the percentage of individuals aged greater than 65 years."----
+## ----spatial01-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:spatial01}Figure 12: Map of an area of New York, USA showing for each census tract the percentage of individuals aged greater than 65 years."----
 ggplot() + 
    theme_bw() +
    geom_sf(data = nyage65utm.sf, aes(fill = PCTAGE65P), colour = "dark grey") + 
@@ -220,7 +217,6 @@ ggplot() +
    labs(fill = "Age >65 years") +
    theme(legend.position = "bottom", legend.key.width = unit(1.0, "cm"))
 
-
 ## ----message = FALSE----------------------------------------------------------
 data(chorley)
 chorley.df <- data.frame(xcoord = chorley$x * 1000, ycoord = chorley$y * 1000, status = chorley$marks)
@@ -247,7 +243,7 @@ mformat <- function(){
    function(x) format(x / 1000, digits = 2)
 }
 
-## ----spatial02-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:spatial02}Figure 13: Point map showing the place of residence of individuals diagnosed with laryngeal cancer (Pos) and lung cancer (Neg), Copull Lancashire, UK, 1972 to 1980."----
+## ----spatial02-fig, warnings = FALSE, echo = TRUE, fig.show = "hide", fig.cap="\\label{fig:spatial02}Figure 13: Point map showing the place of residence of individuals diagnosed with laryngeal cancer and lung cancer, Copull Lancashire, UK, 1972 to 1980."----
 ggplot() +
   theme_bw() +
   geom_sf(data = chlarynxbng.sf, aes(colour = status, shape = status)) +
@@ -257,5 +253,5 @@ ggplot() +
   scale_shape_manual(name = "Type", values = c(1,16)) +
   scale_x_continuous(name = "Easting (km)", labels = mformat()) +
   scale_y_continuous(name = "Northing (km)", labels = mformat()) +
-  theme(legend.position = "inside", legend.position.inside = c(0.10, 0.12))
+  theme(legend.position = "bottom")
 
